![MikroE](http://www.mikroe.com/img/designs/beta/logo_small.png)

---

# Secure7 Click

---

- **CIC Prefix**  : SECURE7
- **Author**      : Nenad Filipovic
- **Verison**     : 1.0.0
- **Date**        : Oct 2019.

---

- **Libstock** : ${LIBSTOCK_LINK}
- **HEXIWEAR** : ${HEXI_LINK}
- **GitHub**   : ${GITHUB_LINK}

---

### Software Support

We provide a library for the Secure7 Click on our [LibStock](${LIBSTOCK_LINK}) 
page, as well as a demo application (example), developed using MikroElektronika 
[compilers](http://shop.mikroe.com/compilers). The demo can run on all the main 
MikroElektronika [development boards](http://shop.mikroe.com/development-boards).

**Library Description**

The library covers all the necessary functions to control Secure 7 click board.

Key functions :

- ``` void secure7_send_bytes ( uint8_t count, uint8_t *p_buf ) ``` - Send bytes function.
- ``` void secure7_send_wake_token() ``` - Send wake token function.
- ``` uint8_t secure7_receive_bytes ( uint8_t count, uint8_t *p_buf ) ``` - Receive bytes function.

**Examples Description**

Description :

The application is composed of three sections :

- System Initialization - Initializes GPIO and start to write log.
- Application Initialization - Initialization driver enables - GPIO 
    and configure swi for communication, also write log.
- Application Task - (code snippet) This is an example which demonstrates the use of Secure 7 Click board.
    Data is read from the secure chip. If the read out is successful
    the data is then display on the serial port in the hex format.


```.c

void application_task ( )
{
    if ( atcab_read_serial_number( &buffer_out[ 0 ] ) == ATCA_SUCCESS )
    {
        mikrobus_logWrite( " Serial number : ", _LOG_LINE );
        secure7_output_hex( &buffer_out[ 0 ], 9 );
    }
    else
    {
        mikrobus_logWrite( " Reading serial number failed...", _LOG_LINE );
    }
    
    mikrobus_logWrite( "----------------------------------------", _LOG_LINE );
    Delay_ms ( 1000 );

    if ( atcab_info( &buffer_out[ 0 ] )  == ATCA_SUCCESS )
    {
        mikrobus_logWrite( " Device revision information : ", _LOG_LINE );
        secure7_output_hex( &buffer_out[ 0 ], 4 );
    }
    else
    {
        mikrobus_logWrite( " Reading device revision information failed...", _LOG_LINE );
    }
    
    mikrobus_logWrite( "----------------------------------------", _LOG_LINE );
    Delay_ms ( 1000 );
    
    if ( atcab_read_config_zone( ATECC608A, &buffer_out[ 0 ] ) == ATCA_SUCCESS )
     {
        mikrobus_logWrite( " First 32 bytes of device configuration :",_LOG_LINE );
        secure7_output_hex( &buffer_out[ 0 ], 32 );
     }
     else
     {
        mikrobus_logWrite( " Reading config zone failed...",_LOG_LINE );
     }
    
    mikrobus_logWrite( "----------------------------------------", _LOG_LINE );
    Delay_ms( 10000 );
}

```

Additional Functions :

- ``` secure7_set_output ``` - SWI directions set implementation - output.
- ``` secure7_set_input ``` - SWI directions set implementation - input.
- ``` secure7_output_hex ``` - Display output data in hex format.

The full application code, and ready to use projects can be found on our 
[LibStock](${LIBSTOCK_LINK}) page.

Other mikroE Libraries used in the example:

- GPIO
- UART
- Conversions

**Additional notes and informations**

Depending on the development board you are using, you may need 
[USB UART click](http://shop.mikroe.com/usb-uart-click), 
[USB UART 2 Click](http://shop.mikroe.com/usb-uart-2-click) or 
[RS232 Click](http://shop.mikroe.com/rs232-click) to connect to your PC, for 
development systems with no UART to USB interface available on the board. The 
terminal available in all Mikroelektronika 
[compilers](http://shop.mikroe.com/compilers), or any other terminal application 
of your choice, can be used to read the message.

---
### Architectures Supported

#### mikroC

| STM | KIN | CEC | MSP | TIVA | PIC | PIC32 | DSPIC | AVR | FT90x |
|:-:|:-:|:-:|:-:|:-:|:-:|:-:|:-:|:-:|:-:|
| x | x | x | x | x | x | x | x | x | x |

#### mikroBasic

| STM | KIN | CEC | MSP | TIVA | PIC | PIC32 | DSPIC | AVR | FT90x |
|:-:|:-:|:-:|:-:|:-:|:-:|:-:|:-:|:-:|:-:|
| x | x | x | x | x | x | x | x | x | x |

#### mikroPascal

| STM | KIN | CEC | MSP | TIVA | PIC | PIC32 | DSPIC | AVR | FT90x |
|:-:|:-:|:-:|:-:|:-:|:-:|:-:|:-:|:-:|:-:|
| x | x | x | x | x | x | x | x | x | x |

---
---
